# arpes.fits.lmfit\_html\_repr module

For now we monkeypatch lmfit to make it easier to work with in Jupyter.
We should consider forking or providing a pull at a later date after
this settles down.

The end goal here is to allow pleasing and functional representations of
curve fitting sessions performed in Jupyter, so that they can be rapidly
understood, and screencapped for simple purposes, like including in
group meeting notes.
